##
##  z3.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_z3_base 4.15.1
%define       V_z3_snap 20250611

#   package information
Name:         z3
Summary:      Z3 Theorem Prover
URL:          https://github.com/Z3Prover/z3
Vendor:       Microsoft Research
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Algorithm
License:      MIT
Version:      %{V_z3_base}.%{V_z3_snap}
Release:      20250612

#   package options
%option       with_python  no

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/z3/z3-%{V_z3_snap}.tar.xz
Patch0:       z3.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, python
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  gmp
PreReq:       gmp
%if "%{with_python}" == "yes"
PreReq:       python
%endif

%description
    Z3 is a state-of-the-art theorem prover from Microsoft Research. It
    can be used to check the satisfiability of logical formulas over one
    or more theories. Z3 offers a compelling match for software analysis
    and verification tools, since several common software constructs map
    directly into supported theories.

%track
    prog z3:base = {
        version   = %{V_z3_base}
        url       = https://github.com/Z3Prover/z3/releases
        regex     = tree/z3-(__VER__)
    }
    prog z3:snap = {
        version   = %{V_z3_snap}
        url       = http://download.openpkg.org/components/versioned/z3/
        regex     = z3-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n z3
    %patch -p0

%build
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=$RPM_BUILD_ROOT%{l_prefix} \
        --gmp \
%if "%{with_python}" == "yes"
        --python \
        --pypkgdi=$RPM_BUILD_ROOT%{l_prefix}/lib/python/site-packages \
%endif
        --staticlib
    (   cd build
        %{l_make} %{l_mflags -O}
    ) || exit $?

%install
    ( cd build
      %{l_make} %{l_mflags} install
    ) || exit $?
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

